import { ITextField, ITextFieldProps } from './TextField.Props';
import { BaseComponent } from '../../Utilities';
export interface ITextFieldState {
    value?: string;
    /** Is true when the control has focus. */
    isFocused?: boolean;
    /**
     * The validation error message.
     *
     * - If there is no validation error or we have not validated the input value, errorMessage is an empty string.
     * - If we have done the validation and there is validation error, errorMessage is the validation error message.
     */
    errorMessage?: string;
}
export declare class TextField extends BaseComponent<ITextFieldProps, ITextFieldState> implements ITextField {
    static defaultProps: ITextFieldProps;
    private _id;
    private _descriptionId;
    private _delayedValidate;
    private _isMounted;
    private _lastValidation;
    private _latestValue;
    private _latestValidateValue;
    private _isDescriptionAvailable;
    private _textElement;
    constructor(props: ITextFieldProps);
    /**
     * Gets the current value of the text field.
     */
    readonly value: string;
    componentDidMount(): void;
    componentWillReceiveProps(newProps: ITextFieldProps): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
    /**
     * Sets focus on the text field
     */
    focus(): void;
    /**
     * Selects the text field
     */
    select(): void;
    /**
     * Sets the selection start of the text field to a specified value
     */
    setSelectionStart(value: number): void;
    /**
     * Sets the selection end of the text field to a specified value
     */
    setSelectionEnd(value: number): void;
    private _onFocus(ev);
    private _onBlur(ev);
    private _getTextElementClassName();
    private readonly _errorMessage;
    private _renderTextArea();
    private _renderInput();
    private _onInputChange(event);
    private _validate(value);
    private _notifyAfterValidate(value, errorMessage);
    private _adjustInputHeight();
}
