define([], function() { return "import * as React from 'react';\r\nimport { IRenderFunction } from '../../Utilities';\r\nimport { Persona } from './Persona';\r\n\r\nexport interface IPersonaProps extends React.HTMLProps<Persona> {\r\n  /**\r\n   * Primary text to display, usually the name of the person.\r\n   */\r\n  primaryText?: string;\r\n\r\n  /**\r\n   * Optional custom renderer for the primary text.\r\n   */\r\n  onRenderPrimaryText?: IRenderFunction<IPersonaProps>;\r\n\r\n  /**\r\n   * Decides the size of the control.\r\n   * @defaultvalue PersonaSize.regular\r\n   */\r\n  size?: PersonaSize;\r\n\r\n  /**\r\n   * If true, adds the css class 'is-fadeIn' to the image.\r\n   */\r\n  imageShouldFadeIn?: boolean;\r\n\r\n  /**\r\n   * If true, the image starts as visible and is hidden on error. Otherwise, the image is hidden until\r\n   * it is successfully loaded. This disables imageShouldFadeIn.\r\n   * @defaultvalue false\r\n   */\r\n  imageShouldStartVisible?: boolean;\r\n\r\n  /**\r\n   * Url to the image to use, should be a square aspect ratio and big enough to fit in the image area.\r\n   */\r\n  imageUrl?: string;\r\n\r\n  /**\r\n   * The user's initials to display in the image area when there is no image.\r\n   * @defaultvalue [Derived from primaryText]\r\n   */\r\n  imageInitials?: string;\r\n\r\n  /**\r\n   * Optional custom renderer for the initials\r\n   */\r\n  onRenderInitials?: IRenderFunction<IPersonaProps>;\r\n\r\n  /**\r\n   * The background color when the user's initials are displayed.\r\n   * @defaultvalue [Derived from primaryText]\r\n   */\r\n  initialsColor?: PersonaInitialsColor;\r\n\r\n  /**\r\n   * Presence of the person to display - will not display presence if undefined.\r\n   * @defaultvalue PersonaPresence.none\r\n   */\r\n  presence?: PersonaPresence;\r\n\r\n  /**\r\n   * Secondary text to display, usually the role of the user.\r\n   */\r\n  secondaryText?: string;\r\n\r\n  /**\r\n   * Optional custom renderer for the secondary text.\r\n   */\r\n  onRenderSecondaryText?: IRenderFunction<IPersonaProps>;\r\n\r\n  /**\r\n   * Tertiary text to display, usually the status of the user.\r\n   */\r\n  tertiaryText?: string;\r\n\r\n  /**\r\n   * Optional custom renderer for the tertiary text.\r\n   */\r\n  onRenderTertiaryText?: IRenderFunction<IPersonaProps>;\r\n\r\n  /**\r\n   * Optional text to display, usually a custom message set.\r\n   */\r\n  optionalText?: string;\r\n\r\n  /**\r\n   * Optional custom renderer for the optional text.\r\n   */\r\n  onRenderOptionalText?: IRenderFunction<IPersonaProps>;\r\n\r\n  /**\r\n   * Whether to not render persona details, and just render the persona image/initials.\r\n   */\r\n  hidePersonaDetails?: boolean;\r\n\r\n  /**\r\n   * Additional CSS class(es) to apply to the Persona\r\n   */\r\n  className?: string;\r\n}\r\n\r\nexport enum PersonaSize {\r\n  tiny = 0,\r\n  extraExtraSmall = 1,\r\n  extraSmall = 2,\r\n  small = 3,\r\n  regular = 4,\r\n  large = 5,\r\n  extraLarge = 6\r\n}\r\n\r\nexport enum PersonaPresence {\r\n  none = 0,\r\n  offline = 1,\r\n  online = 2,\r\n  away = 3,\r\n  dnd = 4,\r\n  blocked = 5,\r\n  busy = 6\r\n}\r\n\r\nexport enum PersonaInitialsColor {\r\n  lightBlue = 0,\r\n  blue = 1,\r\n  darkBlue = 2,\r\n  teal = 3,\r\n  lightGreen = 4,\r\n  green = 5,\r\n  darkGreen = 6,\r\n  lightPink = 7,\r\n  pink = 8,\r\n  magenta = 9,\r\n  purple = 10,\r\n  black = 11,\r\n  orange = 12,\r\n  red = 13,\r\n  darkRed = 14\r\n}\r\n"; });