module.exports = "import * as React from 'react';\r\n\r\nexport interface IImageProps extends React.HTMLProps<HTMLImageElement> {\r\n  /**\r\n   * If true, fades the image in when loaded.\r\n   * @defaultvalue false;\r\n   */\r\n  shouldFadeIn?: boolean;\r\n\r\n  /**\r\n   * If true, the image starts as visible and is hidden on error. Otherwise, the image is hidden until\r\n   * it is successfully loaded. This disables shouldFadeIn.\r\n   * @defaultvalue false;\r\n   */\r\n  shouldStartVisible?: boolean;\r\n\r\n  /**\r\n   * If provided, adds the indicated css class to the image.\r\n   */\r\n  className?: string;\r\n\r\n  /**\r\n   * Used to determine how the image is scaled and cropped to fit the frame.\r\n   *\r\n   * @defaultvalue If both dimensions are provided, then the image is fit using ImageFit.scale. Otherwise, the\r\n   * image won't be scaled or cropped.\r\n   */\r\n  imageFit?: ImageFit;\r\n\r\n  /**\r\n   * @deprecated\r\n   * Deprecated at v1.3.6, to be removed at >= v2.0.0.\r\n   * To replace the src in case of errors, use onLoadingStateChange instead and rerender the Image with a \r\n   * difference src.\r\n   */\r\n  errorSrc?: string;\r\n\r\n  /**\r\n   * If true, the image frame will expand to fill its parent container.\r\n   */\r\n  maximizeFrame?: boolean;\r\n\r\n  /**\r\n   * Optional callback method for when the image load state has changed.\r\n   * The 'loadState' parameter indicates the current state of the Image.\r\n   */\r\n  onLoadingStateChange?: (loadState: ImageLoadState) => void;\r\n}\r\n\r\n/**\r\n * The possible methods that can be used to fit the image.\r\n */\r\nexport enum ImageFit {\r\n  /**\r\n   * The image is not scaled. The image is centered and cropped within the content box.\r\n   */\r\n  center = 0,\r\n\r\n  /**\r\n   * The image is scaled to maintain its aspect ratio while being fully contained within the frame. The image will\r\n   * be centered horizontally and vertically within the frame. The space in the top and bottom or in the sides of\r\n   * the frame will be empty depending on the difference in aspect ratio between the image and the frame.\r\n   */\r\n  contain = 1,\r\n\r\n  /**\r\n   * The image is scaled to maintain its aspect ratio while filling the frame. Portions of the image will be cropped from\r\n   * the top and bottom, or from the sides, depending on the difference in aspect ratio between the image and the frame.\r\n   */\r\n  cover = 2,\r\n\r\n  /**\r\n   * Neither the image nor the frame are scaled. If their sizes do not match, the image will either be cropped or the\r\n   * frame will have empty space.\r\n   */\r\n  none = 3\r\n}\r\n\r\nexport enum ImageLoadState {\r\n  /**\r\n   * The image has not yet been loaded, and there is no error yet.\r\n   */\r\n  notLoaded = 0,\r\n\r\n  /**\r\n   * The image has been loaded successfully.\r\n   */\r\n  loaded = 1,\r\n\r\n  /**\r\n   * An error has been encountered while loading the image.\r\n   */\r\n  error = 2,\r\n\r\n  /**\r\n   * @deprecated\r\n   * Deprecated at v1.3.6, to be removed at >= v2.0.0.\r\n   * To replace the src in case of errors, use onLoadingStateChange instead and rerender the Image with a \r\n   * difference src.\r\n   */\r\n  errorLoaded = 3\r\n}\r\n";