module.exports = "import * as React from 'react';\r\nimport { IPickerItemProps } from './PickerItem.Props';\r\nimport { IRenderFunction } from '../../Utilities';\r\n\r\n// Type T is the type of the item that is displayed\r\n// and searched for by the people picker. For example, if the picker is\r\n// displaying persona's than type T could either be of Persona or Ipersona props\r\nexport interface IBasePickerProps<T> extends React.Props<any> {\r\n  /**\r\n   * Function that specifies how the selected item will appear.\r\n   */\r\n  onRenderItem?: (props: IPickerItemProps<T>) => JSX.Element;\r\n  /**\r\n   * Function that specifies how an individual suggestion item will appear.\r\n   */\r\n  onRenderSuggestionsItem?: (props: T) => JSX.Element;\r\n  /**\r\n   * A callback for what should happen when a person types text into the input.\r\n   * Returns the already selected items so the resolver can filter them out.\r\n   */\r\n  onResolveSuggestions: (filter: string, selectedItems?: T[]) => T[] | PromiseLike<T[]>;\r\n  /**\r\n   * Initial items that have already been selected and should appear in the people picker.\r\n   */\r\n  defaultSelectedItems?: T[];\r\n  /**\r\n   * A callback for when the selected list of items changes.\r\n   */\r\n  onChange?: (items?: T[]) => void;\r\n  /**\r\n   * A callback to get text from an item. Used to autofill text in the pickers.\r\n   */\r\n  getTextFromItem?: (item: T, currentValue?: string) => string;\r\n  /**\r\n   * A callback that gets the rest of the results when a user clicks get more results.\r\n   */\r\n  onGetMoreResults?: (filter: string, selectedItems?: T[]) => T[] | PromiseLike<T[]>;\r\n  /**\r\n   * ClassName for the picker.\r\n   */\r\n  className?: string;\r\n  /**\r\n   * The properties that will get passed to the Suggestions component.\r\n   */\r\n  pickerSuggestionsProps?: IBasePickerSuggestionsProps;\r\n\r\n  /**\r\n   * AutoFill input native props\r\n   * @default undefined\r\n   */\r\n  inputProps?: React.HTMLProps<HTMLInputElement>;\r\n}\r\n\r\nexport interface IBasePickerSuggestionsProps {\r\n  /**\r\n  * Function that specifies what to render when no results are found.\r\n  */\r\n  onRenderNoResultFound?: IRenderFunction<void>;\r\n  /**\r\n   * The text that should appear at the top of the suggestion box.\r\n   */\r\n  suggestionsHeaderText?: string;\r\n  /**\r\n   * the text that should appear when no results are returned.\r\n   */\r\n  noResultsFoundText?: string;\r\n  /**\r\n   * ClassName for the picker.\r\n   */\r\n  className?: string;\r\n  /**\r\n   * Classname for the suggestion box.\r\n   */\r\n  suggestionsClassName?: string;\r\n  /**\r\n   * ClassName for suggestion items.\r\n   */\r\n  suggestionsItemClassName?: string;\r\n  /**\r\n   * The text that should appear on the button to search for more.\r\n   */\r\n  searchForMoreText?: string;\r\n  /**\r\n   * The text to display while the results are loading.\r\n   */\r\n  loadingText?: string;\r\n}";